# RedisWQ

This package is based on the `rediswq.py` file that the
[Kubernetes Tutorial for Fine Parallel Processing Using a Work Queue](https://kubernetes.io/docs/tasks/job/fine-parallel-processing-work-queue/) uses.

While the code itself seems to be quite solid, there are currently no tests
and no documentation available.

I'm hoping to add both in the future.
